==> haskell-geniplate-mirror-0.7.10-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.10
visibility:           public
id:                   geniplate-mirror-0.7.10-BbmPvP2C40r3rQ8NmaAwa4
key:                  geniplate-mirror-0.7.10-BbmPvP2C40r3rQ8NmaAwa4
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  2501f0a55cc6a24232433f9bc8b8497c
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/geniplate-mirror-0.7.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/geniplate-mirror-0.7.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-geniplate-mirror
hs-libraries:         HSgeniplate-mirror-0.7.10-BbmPvP2C40r3rQ8NmaAwa4
depends:              base-4.16.4.0 mtl-2.2.2 template-haskell-2.18.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-geniplate-mirror-0.7.10-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 geniplate-mirror
version:              0.7.10
visibility:           public
id:                   geniplate-mirror-0.7.10-25lIXRK8ttbFFgvG3SVKfe
key:                  geniplate-mirror-0.7.10-25lIXRK8ttbFFgvG3SVKfe
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  6216d0354ab04c58eff64222d4253f7d
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/geniplate-mirror-0.7.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/geniplate-mirror-0.7.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/geniplate-mirror-0.7.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-geniplate-mirror
hs-libraries:         HSgeniplate-mirror-0.7.10-25lIXRK8ttbFFgvG3SVKfe
depends:              base-4.17.2.1 mtl-2.2.2 template-haskell-2.19.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
